#include <iostream>
#include <algorithm>
#include <vector>
#include <queue>
#include <list>
using namespace std;

const int LOW_PRIOR = INT_MAX / 4 - 1;

struct pt {
	bool sorted = false;
	int c;
	pt(int k) : c(k) {}
	pt(int k, queue<int> &v) : c(k), prior(v) {}
	queue<int> prior;

	int get_p() const {
		if (prior.empty())
			return -1;
		else
			return prior.front();
	}

	void use() {
		prior.pop();
	}

	bool operator <(const pt &rhs) const {
		return get_p() < rhs.get_p();
	}

	bool operator ==(const pt &rhs) const {
		return c == rhs.c;
	}
};

list<pt> order; // order of card in the robot
vector<int> queries;
vector<queue<int>> priority; // get next priority

int main() {
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);

	int n, m;
	cin >> n >> m;
	priority.resize(n);
	queries.resize(m);

	for (int i = 0; i < m; ++i) {
		int query;
		cin >> query;
		--query;
		queries[i] = query;
		priority[query].push(i);
	}

	for (int i = 0; i < n; ++i) {
		int card;
		cin >> card;
		--card;
		order.emplace_back(pt(card, priority[card]));
	}

	auto fnd = [&](int k) {
		return find(order.begin(), order.end(), pt(k));
	};

	auto dst = [&](list<pt>::iterator it) {
		return distance(order.begin(), it);
	};

	vector<int> asw;
	for (int i = 0; i < m; ++i) {
		int q = queries[i];
		auto pos = dst(fnd(q));
		for (int t = 0; t <= pos; ++t) {
			if (t == pos) 
				order.front().use();

			int prior = order.front().get_p();
			if (prior == -1) {
				asw.push_back(n);
				order.pop_front();
				continue;
			}

			int npos = 0; 
			list<pt>::iterator it, mxsort = order.end();
			for (int j = i; j < prior; ++j) {
				auto gg = fnd(queries[j]);
				if (gg->sorted) {
					if (mxsort == order.end())
						mxsort = gg;
					if (mxsort->get_p() < gg->get_p())
						mxsort = gg;
					continue;
				}
				auto dist = dst(gg);
				if (dist >= npos) {
					npos = dist;
					it = gg;
				}
			}
			if (mxsort != order.end() && dst(mxsort) >= npos) {
				npos = dst(mxsort);
				it = mxsort;
			}

			asw.push_back(npos + 1);
			order.front().sorted = true;
			order.insert(++it, order.front());
			order.pop_front();
		}
	} 

	cout << asw.size() << endl;
	for (auto &x : asw)
		cout << x << " ";
	cout << endl;

	//system("pause>nul");
	return 0;
}

/*
4 5
4 1 2 4 4
4 3 2 1
*/